@@ -1,7 +1,7 @@
 /* revision.h -- define the version number
 
-   Copyright (C) 1998-1999, 2001-2002, 2006, 2009 Free Software Foundation,
-   Inc.
+   Copyright (C) 1998-1999, 2001-2002, 2006, 2009-2010 Free Software
+   Foundation, Inc.
    Copyright (C) 1992-1993 Jean-loup Gailly.
 
    This program is free software; you can redistribute it and/or modify
